/*
 * Copyright 2007-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package org.impalaframework.spring;

import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.context.ApplicationEvent;
import org.springframework.context.ApplicationListener;

/**
 * Base implementation of {@link ApplicationListener} which only propagats event if the source of the event is itself
 * @author Phil Zoio
 */
public abstract class SelfAwareApplicationListenerAdapter implements ApplicationListener<ApplicationEvent>, ApplicationContextAware {
    
    private ApplicationContext applicationContext;
    
    public final void onApplicationEvent(ApplicationEvent event) {
        final Object source = event.getSource();
        if (source == applicationContext) {
            inApplicationEvent(event);
        }
    }
    
    /**
     * Method for subclasses to implement
     */
    protected abstract void inApplicationEvent(ApplicationEvent event);

    public void setApplicationContext(ApplicationContext applicationContext)
            throws BeansException {
        this.applicationContext = applicationContext;
    }

}
